#include <gtk/gtk.h>

#ifdef HILDON
#  include <hildon-widgets/hildon-window.h>

gboolean key_press_cb(GtkWidget * widget, GdkEventKey * event,
		                      HildonWindow * window);
#endif


void
on_b_ok_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_b_ok2_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_b_ok3_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_b_ok4_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_b_close_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_file_browse_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_file_browse2_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_file_browse3_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_file_browse4_clicked                        (GtkButton       *button,
                                        gpointer         user_data);

// NES Sound toggle clicked
void on_cb_sound2_clicked(GtkToggleButton *button, gpointer user_data);

gboolean
on_mainwindow_destroy_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

